##  Creating Your First S-User Administrator
### Prerequisites
You have access to the SAP Sales Order document and the SAP Onboarding Portal.
### Context
Super/cloud administrators can choose a user to handle user management and permissions for their organization. They use a User Onboarding Token for this process. This setup ensures someone in your organization can manage SAP access. Learn more about [User Onboarding Tokens![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Fmy-support%2Fusers%2Fuser-onboarding-token.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/en/my-support/users/user-onboarding-token.html").
**Note**
You can only redeem a User Onboarding Token once.
### Procedure
  1. Open your SAP sales order document.
  2. Scroll to the section AUTHORIZED ADMINISTRATORS and find the line that says User Onboarding Token. Copy the token listed.
  3. Go to the [SAP Onboarding Portal![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Faccount.sap.com%2Fonboard%2F "https://account.sap.com/onboard/") and choose Start.
  4. Paste the token you copied from the sales order into the field User Onboarding Token
  5. Enter the new administrator details by filling in the required fields:
    1. First and last name
    2. Email address
    3. Company details (if prompted)
  6. Verify your corporate email address and complete your account setup.


### Results
SAP updates the administrator in the SAP systems with the name of the person who redeemed the token.
The administrator S-user is created and assigned to the person who redeemed the token. This person will receive all technical product-related notifications, renewal notices, and S-user lifetime notifications.
